@@ -50,5 +50,5 @@ impl Column for SecContext {
         self.raw_contents.insert(proc.pid, raw_content);
     }
 
-    column_default!(String);
+    column_default!(String, false);
 }
